<?php
/**
 * Order Customer Details
 *
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 8.7.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$customer_note = $order->get_customer_note();
$billing_email = $order->get_billing_email();
$billing_phone = $order->get_billing_phone();

$show_shipping = ! wc_ship_to_billing_address_only() && $order->needs_shipping_address();
?>
<header><h2><?php esc_html_e( 'Customer Details', 'adventure-tours' ); ?></h2></header>

<table class="shop_table shop_table_responsive customer_details">
	<?php if ( !empty( $customer_note ) ) : ?>
		<tr>
			<th><?php esc_html_e( 'Note', 'adventure-tours' ) . ':'; ?></th>
			<td data-title="<?php esc_attr_e( 'Note', 'adventure-tours' ); ?>"><?php echo wptexturize( $customer_note ); ?></td>
		</tr>
	<?php endif; ?>

	<?php if ( !empty( $billing_email ) ) : ?>
		<tr>
			<th><?php esc_html_e( 'Email', 'adventure-tours' ) . ':'; ?></th>
			<td data-title="<?php esc_attr_e( 'Email', 'adventure-tours' ); ?>"><?php echo esc_html( $billing_email ); ?></td>
		</tr>
	<?php endif; ?>

	<?php if ( !empty( $billing_phone ) ) : ?>
		<tr>
			<th><?php esc_html_e( 'Telephone', 'adventure-tours' ) . ':'; ?></th>
			<td data-title="<?php esc_attr_e( 'Telephone', 'adventure-tours' ); ?>"><?php echo esc_html( $billing_phone ); ?></td>
		</tr>
	<?php endif; ?>
</table>

<?php if ( $show_shipping ) : ?>

<div class="col2-set addresses">
	<div class="col-1">

<?php endif; ?>

<header class="title">
	<h3><?php esc_html_e( 'Billing Address', 'adventure-tours' ); ?></h3>
</header>
<address>
	<?php echo wp_kses_post( $order->get_formatted_billing_address( esc_html__( 'N/A', 'adventure-tours' ) ) ); ?>

	<?php
		/**
		 * Action hook fired after an address in the order customer details.
		 *
		 * @since 8.7.0
		 * @param string $address_type Type of address (billing or shipping).
		 * @param WC_Order $order Order object.
		 */
		do_action( 'woocommerce_order_details_after_customer_address', 'billing', $order );
	?>
</address>

<?php if ( $show_shipping ) : ?>

	</div><!-- /.col-1 -->
	<div class="col-2">
		<header class="title">
			<h3><?php esc_html_e( 'Shipping Address', 'adventure-tours' ); ?></h3>
		</header>
		<address>
			<?php if ( version_compare( WC_VERSION, '5.6.0', '>=' ) && $order->get_shipping_phone() ) : ?>
				<p class="woocommerce-customer-details--phone"><?php echo esc_html( $order->get_shipping_phone() ); ?></p>
			 <?php endif; ?>

			<?php echo wp_kses_post( $order->get_formatted_shipping_address( esc_html__( 'N/A', 'adventure-tours' ) ) ); ?>

			<?php
				/**
				 * Action hook fired after an address in the order customer details.
				 *
				 * @since 8.7.0
				 * @param string $address_type Type of address (billing or shipping).
				 * @param WC_Order $order Order object.
				 */
				do_action( 'woocommerce_order_details_after_customer_address', 'shipping', $order );
			?>
		</address>
	</div><!-- /.col-2 -->
</div><!-- /.col2-set -->

<?php endif; ?>

<?php do_action( 'woocommerce_order_details_after_customer_details', $order ); ?>
